local Sorcerer = ...

-- Register common prefab nodes
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_0_RootPart", _SorcererPrefix .. "2_ROOT_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_0_Tiling0Part", _SorcererPrefix .. "2_TILING0_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_1_Tiling1Part", _SorcererPrefix .. "2_TILING1_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_2_Tiling2Part", _SorcererPrefix .. "2_TILING2_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_3_Tiling3Part", _SorcererPrefix .. "2_TILING3_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart", _SorcererPrefix .. "2_TOP_PREFAB")

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	Sorcerer:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		ConstructorData = {
                     DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                     CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                }
	})
end

local defaultNodePrefixList = {
	_SorcererPrefix .. "2_TOP",
	_SorcererPrefix .. "2_TILING0",
	_SorcererPrefix .. "2_TILING1",
	_SorcererPrefix .. "2_TILING2",
	_SorcererPrefix .. "2_TILING3"
}

-- Register simple building part assets
for i, nodePrefix in ipairs(defaultNodePrefixList) do
	registerDefaultBuildingPart(nodePrefix)
end

-- Register the sorcerer house part
Sorcerer:register({
	DataType = "BUILDING_PART",
	Id = _SorcererPrefix .. "2_ROOT_PART",
	Name = _SorcererPrefix .. "2_ROOT_NAME",
	Description = _SorcererPrefix .. "2_ROOT_DESC",
	Category = "CORE",
        BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4, 4} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }},
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _SorcererPrefix .. "2_ROOT_PREFAB",
		EndPart = _SorcererPrefix .. "2_TOP_PART",
		FillerList = {
			_SorcererPrefix .. "2_TILING3_PART",
			_SorcererPrefix .. "2_TILING2_PART",
			_SorcererPrefix .. "2_TILING1_PART"
                },
		BasementFillerList = {
			_SorcererPrefix .. "2_TILING0_PART"
         	},
		MinimumScale = 0,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = 5 }
		}
	},
	AssetBuildingFunction = _SorcererPrefix .. "2_FUNCTION"
})
Sorcerer:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = "SORCERER2_FUNCTION",
		WorkerCapacity = 1,
                RelatedJob = { Job = _SorcererPrefix, Behavior = "BEHAVIOR_WORK" }
})


-- Register particule systems attachments
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/SmokeEmitter", _SorcererPrefix .. "2_SMOKE_EMITTER_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitter", _SorcererPrefix .. "2_BAT_EMITTER_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitterBack", _SorcererPrefix .. "2_BAT_EMITTER_BACK_PREFAB")

Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart", {
	DataType = "COMP_BUILDING_PART",
	FeedbackComponentListToActivate = {
                 { _SorcererPrefix .. "2_SMOKE_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" },
                 { _SorcererPrefix .. "2_BAT_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" },
                 { _SorcererPrefix .. "2_BAT_EMITTER_BACK_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" }
	}
})

-- Register air vent particle system
Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_BLACKSMITH_ROCK",
	IsPlaying = true,
	IsEmitting = false
})

Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})

-- Register air vent particle system
Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "BAT2_PARTICLE_SYSTEM",
	IsPlaying = true,
	IsEmitting = false
})

Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})

-- Register air vent particle system
Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitterBack", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "BAT2_PARTICLE_SYSTEM_BACK",
	IsPlaying = true,
	IsEmitting = false
})

Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitterBack", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})

-- Register grounding components
Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_0_Tiling0Part/porte", {
	DataType = "COMP_GROUNDED"
})


